<?php
/**
 * Admin class
 *
 * @since 1.0
 */
namespace dodebug;

defined( 'WPINC' ) || exit;

class Admin extends Instance
{
	protected static $_instance;

	/**
	 * Init admin
	 *
	 * @since  1.0
	 * @access public
	 */
	public function init()
	{
		defined( 'debug' ) && debug2( '[admin] init' );

		add_action( 'admin_menu', array( $this, 'admin_menu' ) );
		add_filter( 'plugin_action_links_dodebug/dodebug.php', array( $this, 'add_plugin_links' ) );
		add_action( 'admin_init', array( $this, 'admin_init' ) );
	}

	/**
	 * Admin setting page
	 *
	 * @since  1.0
	 * @access public
	 */
	public function admin_menu()
	{
		add_options_page( 'DoDebug', 'DoDebug', 'manage_options', 'dodebug', array( $this, 'setting_page' ) );
	}

	/**
	 * admin_init
	 *
	 * @since  1.0
	 * @access public
	 */
	public function admin_init()
	{
		if ( get_transient( 'dodebug_activation_redirect' ) ) {
			delete_transient( 'dodebug_activation_redirect' );
			if ( ! is_network_admin() && ! isset( $_GET['activate-multi'] ) ) {
				wp_safe_redirect( menu_page_url( 'dodebug', 0 ) );
			}
		}
	}

	/**
	 * Plugin link
	 *
	 * @since  1.0
	 * @access public
	 */
	public function add_plugin_links( $links )
	{
		$links[] = '<a href="' . menu_page_url( 'dodebug', 0 ) . '">' . __( 'Settings', 'dodebug' ) . '</a>';

		return $links;
	}

	/**
	 * Display and save options
	 *
	 * @since  1.0
	 * @access public
	 */
	public function setting_page()
	{
		if ( ! empty( $_POST ) ) {
			check_admin_referer( 'dodebug' );

			// Save options
			$list = array() ;

			foreach ( Conf::get_instance()->get_options() as $id => $v ) {
				if ( $id == '_ver' ) {
					continue;
				}

				$list[ $id ] = ! empty( $_POST[ $id ] ) ? sanitize_textarea_field( $_POST[ $id ] ) : false ;
			}

			// Special handler for list
			$list[ 'admin_ip' ] = $this->_sanitize_list( $_POST[ 'admin_ip' ] );

			foreach ( $list as $id => $v ) {
				Conf::update( $id, $v );
			}
		}

		require_once DODEBUG_DIR . 'tpl/settings.tpl.php';
	}

	/**
	 * Sanitize list
	 *
	 * @since  1.0
	 * @access public
	 */
	private function _sanitize_list( $list )
	{
		if ( ! is_array( $list ) ) {
			$list = explode( "\n", trim( $list ) );
		}

		foreach ( $list as $k => $v ) {
			$list[ $k ] = implode( ', ', array_map( 'trim', explode( ',', $v ) ) );
		}

		return array_filter( $list );
	}

}